@@ -1,8 +1,8 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /cvsroot/pgpool/pgpool-II/parser/pool_string.h,v 1.2 2007/01/04 17:27:11 devrim Exp $
+ * $Header: /cvsroot/pgpool/pgpool-II/parser/pool_string.h,v 1.4 2008/01/29 01:56:39 y-asaba Exp $
  *
- * Copyright (c) 2006-2007, pgpool Global Development Group
+ * Copyright (c) 2006-2008, pgpool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -19,8 +19,6 @@
 #ifndef POOL_STRING_H
 #define POOL_STRING_H
 
-#include "pg_list.h"
-
 #define STRING_SIZE 128
 
 typedef struct
@@ -35,6 +33,5 @@ extern void string_append_string(String *string, String *append_data);
 extern void string_append_char(String *string, char *append_data);
 extern void free_string(String *string);
 extern String *copy_string(String *string);
-extern char *NameListToQuotedString(List *names);
 
 #endif /* POOL_STRING_H */
