@@ -1,12 +1,12 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /cvsroot/pgpool/pgpool-II/pool_proto_modules.h,v 1.24 2010/09/27 02:01:57 kitagawa Exp $
+ * $Header: /cvsroot/pgpool/pgpool-II/pool_proto_modules.h,v 1.32 2011/08/29 07:09:50 kitagawa Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2009	PgPool Global Development Group
+ * Copyright (c) 2003-2011	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -33,9 +33,11 @@
 #include "parser/parsenodes.h"
 #include "pool_rewrite_query.h"
 #include "pool_session_context.h"
+#include "pool_process_reporting.h"
 
 #define SPECIFIED_ERROR 1
-#define POOL_DUMMY_QUERY "DELETE FROM foo WHERE col = 'pgpool: unable to parse the query'"
+#define POOL_DUMMY_WRITE_QUERY "DELETE FROM foo WHERE col = 'pgpool: unable to parse the query'"
+#define POOL_DUMMY_READ_QUERY "SELECT 'pgpool: unable to parse the query'"
 #define POOL_ERROR_QUERY "send invalid query from pgpool to abort transaction"
 
 extern char *copy_table;  /* copy table name */
@@ -43,9 +45,6 @@ extern char *copy_schema;  /* copy table name */
 extern char copy_delimiter; /* copy delimiter char */
 extern char *copy_null; /* copy null string */
 
-/* non 0 if "BEGIN" query with extended query protocol received */
-extern int receive_extended_begin;
-
 extern int is_select_pgcatalog;
 extern int is_select_for_update; /* also for SELECT ... INTO */
 extern bool is_parallel_table;
@@ -150,13 +149,12 @@ extern int RowDescription(POOL_CONNECTION *frontend,
 						  short *result);
 
 
-extern POOL_STATUS wait_for_query_response(POOL_CONNECTION *frontend, POOL_CONNECTION *backend, char *string, int protoVersion);
+extern POOL_STATUS wait_for_query_response(POOL_CONNECTION *frontend, POOL_CONNECTION *backend, int protoVersion);
 extern int is_select_query(Node *node, char *sql);
-extern int is_sequence_query(Node *node);
-extern int is_start_transaction_query(Node *node);
-extern int is_commit_query(Node *node);
-extern int is_strict_query(Node *node); /* returns non 0 if this is strict query */
-extern int load_balance_enabled(POOL_CONNECTION_POOL *backend, Node* node, char *sql);
+extern bool is_commit_query(Node *node);
+extern bool is_rollback_query(Node *node);
+extern bool is_commit_or_rollback_query(Node *node);
+extern bool is_strict_query(Node *node); /* returns non 0 if this is strict query */
 extern int need_insert_lock(POOL_CONNECTION_POOL *backend, char *query, Node *node);
 extern POOL_STATUS insert_lock(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend, char *query, InsertStmt *node, int lock_kind);
 extern char *parse_copy_data(char *buf, int len, char delimiter, int col_id);
@@ -171,13 +169,7 @@ extern int detect_query_cancel_error(POOL_CONNECTION *backend, int major);
 extern bool is_partition_table(POOL_CONNECTION_POOL *backend, Node *node);
 extern POOL_STATUS pool_discard_packet(POOL_CONNECTION_POOL *cp);
 extern void query_cache_register(char kind, POOL_CONNECTION *frontend, char *database, char *data, int data_len);
-
 extern int is_drop_database(Node *node);		/* returns non 0 if this is a DROP DATABASE command */
-extern void config_reporting(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend);
-extern void pools_reporting(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend);
-extern void processes_reporting(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend);
-extern void nodes_reporting(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend);
-extern void version_reporting(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend);
 
 extern POOL_STATUS send_simplequery_message(POOL_CONNECTION *backend, int len, char *string, int major);
 extern POOL_STATUS send_extended_protocol_message(POOL_CONNECTION_POOL *backend,
